@@ -46,3 +46,29 @@ class NonStandardField(models.Model):
     objects = models.Manager()
     with_section = SectionSlugManager(section_field="sections_by_another_name",
             slug_field="slugs_by_another_name")
+
+
+class SectionForeignKeyCommon(models.Model):
+    title = models.CharField(max_length=20)
+    primary_section = models.ForeignKey(Section)
+    slug = models.SlugField()
+
+    objects = InheritanceManager()
+    with_section = SectionSlugManager()
+
+
+class SectionForeignKeyArticle(SectionForeignKeyCommon):
+    summary = models.TextField(default="Default", blank=True)    
+
+
+class ComplexCommon(models.Model):
+    title = models.CharField(max_length=20)
+    primary_section = models.ForeignKey(Section)
+    related_sections = models.ManyToManyField(Section, related_name='relatedcomplexcommon_set')
+    slug = models.SlugField()
+
+    objects = InheritanceManager()
+    with_section = SectionSlugManager()
+
+class ComplexArticle(ComplexCommon):
+    summary = models.TextField(default="Default", blank=True)
